####################################################################
# Trapped Factors and China's Impact on Global Growth
# Bloom, Romer, Terry, Van Reenen
# Run this file to produce Figure 9
# Questions to stephenjamesterry@gmail.com
####################################################################

rm(list=ls())

source("Step_1.R")
source("Step_2.R")
source("Step_3.R")
source("Step_4.R")
source("Step_5.R")

library(matlab)
options(digits=15)
load(file="./Model_Data/graphout_fm_total.rda")
graphout.fm.total=graphout.fm
load(file="./Model_Data/graphout_tf_total.rda")
graphout.tf.total=graphout.tf
load(file="./Model_Data/graphout_tf.rda")
load(file="./Model_Data/graphout_fm.rda")

T = dim(graphout.tf)[1]-1
assign('numyrs',10)

g.phi.prime.total=graphout.fm.total$g[T+1]
q.phi.prime.total=graphout.fm.total$q[T+1]

g.phi = graphout.fm$g[1]
g.phi.prime = graphout.fm$g[T+1]
q.phi=graphout.fm$q[1]
q.phi.prime=graphout.fm$q[T+1]
r.phi=graphout.fm$r[1]
r.phi.prime=graphout.fm$r[T+1]
#create graph A: micro graph

scale = 1000/graphout.fm$M1[1]
numperbefore = 2
numperafter = 5

axis = -numperbefore:numperafter

lwidnum=2

parameters = read.csv('./Model_Data/fm_parameters.csv')
assign('A1',graphout.fm$A[1])
assign('phi',parameters$phi)
assign('phi.prime',parameters$phi.prime)
assign('alpha',parameters$alpha)
assign('H',parameters$H)
assign('Hstar',parameters$Hstar)
assign('gamma',1/parameters$rho)
assign('eta',parameters$eta)
assign('IoverY.open.target',parameters$IoverY.open.target)
assign('IoverY.fully.mobile.target',parameters$IoverY.fully.mobile.target)
assign('beta',parameters$beta);  #discount rate

parameters.tot.imports=read.csv('./Model_Data/outdata_total.csv')
parameter.tot.imports=parameters.tot.imports[2:dim(parameters.tot.imports)[2]]

#SET UP STORAGE
welfare.length = 600
u.mat=zeros(welfare.length,6)
betas=zeros(welfare.length,1)
u.mat[1:(T+1),1]=graphout.tf$u
u.mat[1:(T+1),2]=graphout.tf$ustar
u.mat[1:(T+1),3]=graphout.fm$u
u.mat[1:(T+1),4]=graphout.fm$ustar

#FIRST, COMPUTE THE WELFARE WITH NO SHOCK IN THE WEST AND THE EAST
Mprimeval = g.phi * A1; Mval = Mprimeval / (1+g.phi);
Rprimeval = (1-phi) * A1; Rval = Rprimeval / (1+g.phi);
Iprimeval = phi * A1; Ival = Iprimeval / (1+g.phi);

xMval = (1-alpha)^(2/alpha) * (1+r.phi)^(-1/alpha) * H
xMstarval = (1-alpha)^(2/alpha) * (1+r.phi)^(-1/alpha) * q.phi^(1/alpha) * Hstar

xRval = (1-alpha)^(1/alpha) * (1+r.phi)^(-1/alpha) * H
xRstarval = (1-alpha)^(1/alpha) * (1+r.phi)^(-1/alpha) * Hstar

xIval = (1-alpha)^(1/alpha) * (1+r.phi)^(-1/alpha) * q.phi^(-1/alpha) * H
xIstarval = (1-alpha)^(1/alpha) * (1+r.phi)^(-1/alpha) * Hstar

Zval = (g.phi^gamma)/(eta*(gamma-1)+1)

Yval = H^alpha
Yval = Yval * ( Mval * xMval^(1-alpha) + Rval * xRval^(1-alpha) + Ival * xIval^(1-alpha)  )

Cval = Yval - Mprimeval * (xMval + xMstarval) - Rprimeval * xRval - Zval

Ystarval = Hstar^alpha
Ystarval = Ystarval *  (Mval * xMstarval^(1-alpha) + Rval * xRstarval^(1-alpha) + Ival * xIstarval^(1-alpha)    )

Cstarval = Ystarval - Rprimeval * xRstarval - Iprimeval * (xIval + xIstarval)
#THEN, DISCOUNT ALL FLOWS

betas[1]=beta
u.mat[1,5]=Cval
u.mat[1,6]=Cstarval
for (t in (2:welfare.length)){
  
  u.mat[t,5:6] = u.mat[t-1,5:6]*(1+g.phi)
}

for (t in (2:welfare.length)){
  betas[t]=beta*betas[t-1]
}

for (t in ((T+2):welfare.length)) {
  
  u.mat[t,1:4]=(1+g.phi.prime)*u.mat[t-1,1:4]
  
}

Wtf = sum(betas*log(u.mat[,1]))
Wstartf = sum(betas*log(u.mat[,2]))
Wfm = sum(betas*log(u.mat[,3]))
Wstarfm = sum(betas*log(u.mat[,4]))


x = 100*(exp( (1-beta) *(parameter.tot.imports$Wfm-Wfm)  )-1)
xstar = 100*(exp( (1-beta) *(parameter.tot.imports$Wstarfm-Wstarfm)  )-1)

xtf = 100*(exp( (1-beta) *(parameter.tot.imports$Wtf-Wtf)  )-1)
xstartf = 100*(exp( (1-beta) *(parameter.tot.imports$Wstartf-Wstartf)  )-1)


irate.lim = c(4.0,5.0)
growth.lim = c(1.9,3.5)
xrate.lim= c(0.4,0.75)
mu.lim=c(60,130)
fsize=10
china.col=3
china.sym=2


pdf(file="Figure_9.pdf")
par(mfrow=c(2,1),ps = fsize, cex = 1, cex.main = 1.5,cex.lab=1.5,cex.axis=1)

plot.vec = c(100*((1+g.phi)^(1/numyrs)-1)*ones(numperbefore,1),
             100*((1+graphout.tf.total$g[1:(numperafter+1)])^(1/numyrs)-1))


plot(axis,plot.vec,type="l",main="A: Variety Growth",
     ylim=growth.lim,xlab="Period",ylab="Annual %",col=1,lwd=lwidnum)
points(axis,plot.vec,pch=1,col=1)

plot.vec = c(100*((1+g.phi)^(1/numyrs)-1)*ones(numperbefore,1),
             100*((1+graphout.tf$g[1:(numperafter+1)])^(1/numyrs)-1))
lines(axis,plot.vec,col=china.col,lwd=lwidnum)
points(axis,plot.vec,pch=china.sym,col=china.col)

lines(axis,100*((1+g.phi)^(1/numyrs)-1)*ones((numperbefore+numperafter+1),1),col=2,lty=2,lwd=lwidnum)
lines(axis,100*((1+g.phi.prime.total)^(1/numyrs)-1)*ones((numperbefore+numperafter+1),1),col=4,lwd=lwidnum)
legend("topleft",c("Baseline","No China","Pre-Shock BGP","Baseline Post-Shock BGP"),col=c(1,china.col,2,4),lty=c(1,1,2,1),lwd=lwidnum,bty="n",pch=c(1,china.sym,-1,-1))


plot.vec = c(q.phi*ones(numperbefore,1),
             graphout.tf.total$q[1:(numperafter+1)])


plot(axis,plot.vec,type="l",
     ylim=xrate.lim,main="B: Southern Terms of Trade",xlab="Period",ylab="North/South",col=1,lwd=lwidnum)
points(axis,plot.vec,pch=1,col=1)


plot.vec = c(q.phi*ones(numperbefore,1),
             graphout.tf$q[1:(numperafter+1)])
lines(axis,plot.vec,col=china.col,lwd=lwidnum)
points(axis,plot.vec,pch=china.sym,col=china.col)

lines(axis,q.phi.prime.total*ones((numperbefore+numperafter+1),1),col=4,lwd=lwidnum)
lines(axis,q.phi*ones((numperbefore+numperafter+1),1),col=2,lty=2,lwd=lwidnum)


dev.off()

