####################################################################
# Trapped Factors and China's Impact on Global Growth
# Bloom, Romer, Terry, Van Reenen
# Step 3 in the process of creating Figure 9
# Questions to stephenjamesterry@gmail.com
####################################################################


rm(list=ls())
library(matlab)
options(digits=15)
load(file="./Model_Data/graphout_tf_total.rda")
load(file="./Model_Data/graphout_fm_total.rda")
T = dim(graphout.tf)[1]-1
assign('numyrs',10)

fm.allocations=read.csv("./Model_Data/fm_allocations.csv")
tf.allocations=read.csv("./Model_Data/tf_allocations.csv")

g.phi = graphout.fm$g[1]
g.phi.prime = graphout.fm$g[T+1]
q.phi=graphout.fm$q[1]
q.phi.prime=graphout.fm$q[T+1]
r.phi=graphout.fm$r[1]
r.phi.prime=graphout.fm$r[T+1]
#create graph A: micro graph

scale = 1000/graphout.fm$M1[1]

numperbefore = 2
numperafter = 5

axis = -numperbefore:numperafter
lwidnum=2

parameters = read.csv('./Model_Data/tf_parameters.csv')
assign('A1',graphout.fm$A[1])
assign('phi',parameters$phi)
assign('phi.prime',parameters$phi.prime)
assign('alpha',parameters$alpha)
assign('H',parameters$H)
assign('Hstar',parameters$Hstar)
assign('gamma',1/parameters$rho)
assign('eta',parameters$eta)
assign('IoverY.open.target',parameters$IoverY.open.target)
assign('IoverY.fully.mobile.target',parameters$IoverY.fully.mobile.target)
assign('beta',parameters$beta);  #discount rate

irate.lim = c(4.0,5.5)
growth.lim = c(1.9,3.5)
xrate.lim= c(0.4,0.75)
mu.lim=c(60,130)
fsize=10


#welfare calculations

#SET UP STORAGE
welfare.length = 600
u.mat=zeros(welfare.length,6)
betas=zeros(welfare.length,1)
u.mat[1:(T+1),1]=graphout.tf$u
u.mat[1:(T+1),2]=graphout.tf$ustar
u.mat[1:(T+1),3]=graphout.fm$u
u.mat[1:(T+1),4]=graphout.fm$ustar

#FIRST, COMPUTE THE WELFARE WITH NO SHOCK IN THE WEST AND THE EAST
Mprimeval = g.phi * A1; Mval = Mprimeval / (1+g.phi);
Rprimeval = (1-phi) * A1; Rval = Rprimeval / (1+g.phi);
Iprimeval = phi * A1; Ival = Iprimeval / (1+g.phi);

xMval = (1-alpha)^(2/alpha) * (1+r.phi)^(-1/alpha) * H
xMstarval = (1-alpha)^(2/alpha) * (1+r.phi)^(-1/alpha) * q.phi^(1/alpha) * Hstar

xRval = (1-alpha)^(1/alpha) * (1+r.phi)^(-1/alpha) * H
xRstarval = (1-alpha)^(1/alpha) * (1+r.phi)^(-1/alpha) * Hstar

xIval = (1-alpha)^(1/alpha) * (1+r.phi)^(-1/alpha) * q.phi^(-1/alpha) * H
xIstarval = (1-alpha)^(1/alpha) * (1+r.phi)^(-1/alpha) * Hstar

Zval = (g.phi^gamma)/(eta*(gamma-1)+1)

Yval = H^alpha
Yval = Yval * ( Mval * xMval^(1-alpha) + Rval * xRval^(1-alpha) + Ival * xIval^(1-alpha)  )

Cval = Yval - Mprimeval * (xMval + xMstarval) - Rprimeval * xRval - Zval

Ystarval = Hstar^alpha
Ystarval = Ystarval *  (Mval * xMstarval^(1-alpha) + Rval * xRstarval^(1-alpha) + Ival * xIstarval^(1-alpha)    )

Cstarval = Ystarval - Rprimeval * xRstarval - Iprimeval * (xIval + xIstarval)
#THEN, DISCOUNT ALL FLOWS

betas[1]=beta
u.mat[1,5]=Cval
u.mat[1,6]=Cstarval
for (t in (2:welfare.length)){
  
  u.mat[t,5:6] = u.mat[t-1,5:6]*(1+g.phi)
}

for (t in (2:welfare.length)){
  betas[t]=beta*betas[t-1]
}

for (t in ((T+2):welfare.length)) {
  
  u.mat[t,1:4]=(1+g.phi.prime)*u.mat[t-1,1:4]
  
}

Wtf = sum(betas*log(u.mat[,1]))
Wstartf = sum(betas*log(u.mat[,2]))
Wfm = sum(betas*log(u.mat[,3]))
Wstarfm = sum(betas*log(u.mat[,4]))
Wns = sum(betas*log(u.mat[,5]))
Wstarns = sum(betas*log(u.mat[,6]))

x = 100*(exp( (1-beta) *(Wtf-Wfm)  )-1)
xstar = 100*(exp( (1-beta) *(Wstartf-Wstarfm)  )-1)

xgains = 100*(exp( (1-beta) *(Wfm-Wns)  )-1)
xstargains=100*(exp( (1-beta) *(Wstarfm-Wstarns)  )-1)

xgainstf = 100*(exp( (1-beta) *(Wtf-Wns)  )-1)
xstargainstf=100*(exp( (1-beta) *(Wstartf-Wstarns)  )-1)

#print stuff for robustness spreadsheet
out.data=parameters


out.data=cbind(out.data,out.data[8]/out.data[7])
colnames(out.data)[length(out.data)]="Hstar/H"

out.data=cbind(out.data,100*((1+g.phi)^(1/numyrs)-1))
colnames(out.data)[length(out.data)]="g.phi"

out.data=cbind(out.data,100*((1+g.phi.prime)^(1/numyrs)-1))
colnames(out.data)[length(out.data)]="g.phi.prime"

out.data=cbind(out.data,100*((1+graphout.tf$g[2])^(1/numyrs)-1))
colnames(out.data)[length(out.data)]="g.TF"

out.data=cbind(out.data,100*((1+graphout.fm$g[2])^(1/numyrs)-1))
colnames(out.data)[length(out.data)]="g.FM"

out.data=cbind(out.data,q.phi)
colnames(out.data)[length(out.data)]="q.phi"

out.data=cbind(out.data,q.phi.prime)
colnames(out.data)[length(out.data)]="q.phi.prime"

out.data=cbind(out.data,xgains)
colnames(out.data)[length(out.data)]="North gains trade"

out.data=cbind(out.data,x)
colnames(out.data)[length(out.data)]="North gains TF"

out.data=cbind(out.data,xstargains)
colnames(out.data)[length(out.data)]="South gains trade"

out.data=cbind(out.data,xstar)
colnames(out.data)[length(out.data)]="South gains TF"

out.data=cbind(out.data,100*log(graphout.tf$M2[2]/graphout.tf$M1[2]))
colnames(out.data)[length(out.data)]="Cross-Section Shock - No Shock"

out.data=cbind(out.data,100*log(graphout.tf$M1[2]/graphout.fm$M1[2]))
colnames(out.data)[length(out.data)]="Cross-Section No Shock - FM"

out.data=cbind(out.data,Wtf)
colnames(out.data)[length(out.data)]="Wtf"

out.data=cbind(out.data,Wfm)
colnames(out.data)[length(out.data)]="Wfm"

out.data=cbind(out.data,Wstarfm)
colnames(out.data)[length(out.data)]="Wstarfm"

out.data=cbind(out.data,Wstartf)
colnames(out.data)[length(out.data)]="Wstartf"

out.data=out.data[,2:length(out.data)]

write.csv(file="./Model_Data/outdata_total.csv",out.data)

