####################################################################
# Trapped Factors and China's Impact on Global Growth
# Bloom, Romer, Terry, Van Reenen
# Third of 3 files to run to generate Figures 5,6,7,8,10 & Table 3
# Questions to stephenjamesterry@gmail.com
####################################################################

rm(list=ls())
library(matlab)
options(digits=15)
load(file="graphout_tf.rda")
load(file="graphout_fm.rda")
T = dim(graphout.tf)[1]-1
assign('numyrs',10)

fm.allocations=read.csv("fm_allocations.csv")
tf.allocations=read.csv("tf_allocations.csv")

g.phi = graphout.fm$g[1]
g.phi.prime = graphout.fm$g[T+1]
q.phi=graphout.fm$q[1]
q.phi.prime=graphout.fm$q[T+1]
r.phi=graphout.fm$r[1]
r.phi.prime=graphout.fm$r[T+1]
#create graph A: micro graph

scale = 1000/graphout.fm$M1[1]

numperbefore = 2
numperafter = 5

axis = -numperbefore:numperafter
lwidnum=2

parameters = read.csv('tf_parameters.csv')
assign('A1',graphout.fm$A[1])
assign('phi',parameters$phi)
assign('phi.prime',parameters$phi.prime)
assign('alpha',parameters$alpha)
assign('H',parameters$H)
assign('Hstar',parameters$Hstar)
assign('gamma',1/parameters$rho)
assign('eta',parameters$eta)
assign('IoverY.open.target',parameters$IoverY.open.target)
assign('IoverY.fully.mobile.target',parameters$IoverY.fully.mobile.target)
assign('beta',parameters$beta);  #discount rate

irate.lim = c(4.0,5.5)
growth.lim = c(1.9,3.5)
xrate.lim= c(0.4,0.75)
mu.lim=c(60,130)
fsize=10


bar.data = c(scale*graphout.tf$M2[1],scale*graphout.tf$M1[2],0,scale*graphout.tf$M2[2])
pdf(file="Figure_7.pdf",pointsize=18)
par(ps = 15, cex = 1, cex.main = 1.5,cex.lab=1.5,cex.axis=1)
barplot(bar.data[c(1,2,4)],border=TRUE,density=c(-1,15,15),angle=c(-1,-60,60),space = 0.5,names.arg=c("Pre-Shock","No Shock","Shocked"),
        ylab="New Patent Flows",xlab="Industry",col=c(1,4,2),ylim=c(800,2900),xpd=FALSE)
text(2.55,1900,"36.8%",font=2,cex=1.7)
arrows(3.25,bar.data[2],3.25,bar.data[4],code=3,lwd=1.5,angle=45,length=.2)
text(3.25,2750,"Post-Shock Period",font=2,cex=1.4)
arrows(2.0,2500,4.5,2500,code=3,lwd=1.5,angle=90,length=.2)
dev.off()


pdf(file="Figure_5.pdf")
par(mfrow=c(2,2),ps = fsize, cex = 1, cex.main = 1.5,cex.lab=1.5,cex.axis=1)

plot.vec = c(100*((1+g.phi)^(1/numyrs)-1)*ones(numperbefore,1),
             100*((1+graphout.fm$g[1:(numperafter+1)])^(1/numyrs)-1))

plot(axis,plot.vec,type="l",main="A: Variety Growth",xlab="Period",ylab="Annual %",col=1,lwd=lwidnum,ylim=growth.lim)
points(axis,plot.vec,pch=1)
lines(axis,100*((1+g.phi)^(1/numyrs)-1)*ones((numperbefore+numperafter+1),1),col=2,lty=2,lwd=lwidnum)
lines(axis,100*((1+g.phi.prime)^(1/numyrs)-1)*ones((numperbefore+numperafter+1),1),col=4,lwd=lwidnum)
legend("topright",c("Transition","Pre-Shock BGP","Post-Shock BGP"),cex=1,lty=c(1,2,1),col=c(1,2,4),pch=c(1,-1,-1),bty="n",lwd=lwidnum)



plot.vec = c(q.phi*ones(numperbefore,1),
             graphout.fm$q[1:(numperafter+1)])

plot(axis,plot.vec,type="l",main="B: Southern Terms of Trade",xlab="Period",ylab="North/South",col=1,lwd=lwidnum,
     ylim=xrate.lim)
points(axis,plot.vec,pch=1)
lines(axis,q.phi.prime*ones((numperbefore+numperafter+1),1),col=4,lwd=lwidnum)
lines(axis,q.phi*ones((numperbefore+numperafter+1),1),col=2,lty=2,lwd=lwidnum)



plot.vec = c(100*((1+g.phi)^(1/numyrs)-1)*ones(numperbefore+1,1),
             100*((graphout.fm$Y[2:(numperafter+1)]/graphout.fm$Y[1:numperafter])^(1/numyrs)-1))


plot(axis,plot.vec,type="l",main="C: Northern Output Growth",xlab="Period",ylab="Annual %",col=1,
     lwd=lwidnum,ylim=growth.lim)
points(axis,plot.vec,pch=1)
lines(axis,100*((1+g.phi.prime)^(1/numyrs)-1)*ones((numperbefore+numperafter+1),1),col=4,lwd=lwidnum)
lines(axis,100*((1+g.phi)^(1/numyrs)-1)*ones((numperbefore+numperafter+1),1),col=2,lty=2,lwd=lwidnum)


plot.vec = c(100*((1+g.phi)^(1/numyrs)-1)*ones(numperbefore+1,1),
             100*((graphout.fm$Ystar[2:(numperafter+1)]/graphout.fm$Ystar[1:numperafter])^(1/numyrs)-1))

plot(axis,plot.vec,type="l",main="D: Southern Output Growth",xlab="Period",ylab="Annual %",col=1,
     lwd=lwidnum,ylim=growth.lim)
points(axis,plot.vec,pch=1)
lines(axis,100*((1+g.phi.prime)^(1/numyrs)-1)*ones((numperbefore+numperafter+1),1),col=4,lwd=lwidnum)
lines(axis,100*((1+g.phi)^(1/numyrs)-1)*ones((numperbefore+numperafter+1),1),col=2,lty=2,lwd=lwidnum)

dev.off()

pdf(file="Figure_6.pdf")
par(mfrow=c(2,2),ps = fsize, cex = 1, cex.main = 1.5,cex.lab=1.5,cex.axis=1)

plot.vec = c(100*((1+g.phi)^(1/numyrs)-1)*ones(numperbefore,1),
             100*((1+graphout.tf$g[1:(numperafter+1)])^(1/numyrs)-1))

plot(axis,plot.vec,type="l",main="A: Variety Growth",xlab="Period",ylab="Annual %",col=1,lwd=lwidnum,ylim=growth.lim)
points(axis,plot.vec,pch=1)
lines(axis,100*((1+g.phi)^(1/numyrs)-1)*ones((numperbefore+numperafter+1),1),col=2,lty=2,lwd=lwidnum)
lines(axis,100*((1+g.phi.prime)^(1/numyrs)-1)*ones((numperbefore+numperafter+1),1),col=4,lwd=lwidnum)



plot.vec = c(q.phi*ones(numperbefore,1),
             graphout.tf$q[1:(numperafter+1)])

plot(axis,plot.vec,type="l",main="B: Southern Terms of Trade",xlab="Period",ylab="North/South",col=1,lwd=lwidnum,
     ylim=xrate.lim)
points(axis,plot.vec,pch=1)
lines(axis,q.phi.prime*ones((numperbefore+numperafter+1),1),col=4,lwd=lwidnum)
lines(axis,q.phi*ones((numperbefore+numperafter+1),1),col=2,lty=2,lwd=lwidnum)



plot.vec = c(100*((1+g.phi)^(1/numyrs)-1)*ones(numperbefore+1,1),
             100*((graphout.tf$Y[2:(numperafter+1)]/graphout.tf$Y[1:numperafter])^(1/numyrs)-1))


plot(axis,plot.vec,type="l",main="C: Northern Output Growth",xlab="Period",ylab="Annual %",col=1,
     lwd=lwidnum,ylim=growth.lim)
points(axis,plot.vec,pch=1)
lines(axis,100*((1+g.phi.prime)^(1/numyrs)-1)*ones((numperbefore+numperafter+1),1),col=4,lwd=lwidnum)
lines(axis,100*((1+g.phi)^(1/numyrs)-1)*ones((numperbefore+numperafter+1),1),col=2,lty=2,lwd=lwidnum)

plot.vec = c(100*((1+g.phi)^(1/numyrs)-1)*ones(numperbefore+1,1),
             100*((graphout.tf$Ystar[2:(numperafter+1)]/graphout.tf$Ystar[1:numperafter])^(1/numyrs)-1))

plot(axis,plot.vec,type="l",main="D: Southern Output Growth",xlab="Period",ylab="Annual %",col=1,
     lwd=lwidnum,ylim=growth.lim)
points(axis,plot.vec,pch=1)
lines(axis,100*((1+g.phi.prime)^(1/numyrs)-1)*ones((numperbefore+numperafter+1),1),col=4,lwd=lwidnum)
lines(axis,100*((1+g.phi)^(1/numyrs)-1)*ones((numperbefore+numperafter+1),1),col=2,lty=2,lwd=lwidnum)
legend("topright",c("Transition","Pre-Shock BGP","Post-Shock BGP"),cex=1,lty=c(1,2,1),col=c(1,2,4),pch=c(1,-1,-1),bty="n",lwd=lwidnum)


dev.off()

pdf(file="Figure_8.pdf")
par(mfrow=c(2,2),ps = fsize, cex = 1, cex.main = 1.5,cex.lab=1.5,cex.axis=1)


plot.vec = c(100**ones(numperbefore,1),
             100*tf.allocations$mu2[1:(numperafter+1)])

plot(axis,plot.vec,type="l",main="A: Shocked Shadow Value",xlab="Period",
     ylab="Annual %",col=1,ylim=mu.lim,lwd=lwidnum)
points(axis,plot.vec,,pch=1)
lines(axis,100*ones((numperbefore+numperafter+1),1),col=4,lwd=lwidnum)
legend("topleft",c("Transition","Pre- and Post-Shock BGP"),cex=1,lty=c(1,1),col=c(1,4),pch=c(1,-1,-1),bty="n",lwd=lwidnum)


plot.vec = c(100**ones(numperbefore,1),
             100*tf.allocations$mu1[1:(numperafter+1)])

plot(axis,plot.vec,type="l",main="B: Unshocked Shadow Value",xlab="Period",
     ylab="Annual %",col=1,ylim=mu.lim,lwd=lwidnum)
points(axis,plot.vec,,pch=1)
lines(axis,100*ones((numperbefore+numperafter+1),1),col=4,lwd=lwidnum)


plot.vec = c(100*((1+r.phi)^(1/numyrs)-1)*ones(numperbefore,1),
             100*((1+graphout.tf$r[1:(numperafter+1)])^(1/numyrs)-1))


plot(axis,plot.vec,type="l",
     ylim=irate.lim,main="C: Northern Interest Rate",xlab="Period",ylab="Annual %",col=1,lwd=lwidnum)
points(axis,plot.vec,pch=1)
lines(axis,100*((1+r.phi.prime)^(1/numyrs)-1)*ones((numperbefore+numperafter+1),1),col=4,lwd=lwidnum)
lines(axis,100*((1+r.phi)^(1/numyrs)-1)*ones((numperbefore+numperafter+1),1),col=2,lty=2,lwd=lwidnum)


plot.vec = c(100*((1+r.phi)^(1/numyrs)-1)*ones(numperbefore,1),
             100*((1+graphout.tf$rstar[1:(numperafter+1)])^(1/numyrs)-1))

plot(axis,plot.vec,type="l",
     ylim=irate.lim,main="D: Southern Interest Rate",xlab="Period",ylab="Annual %",col=1,lwd=lwidnum)
points(axis,plot.vec,pch=1)
lines(axis,100*((1+r.phi)^(1/numyrs)-1)*ones((numperbefore+numperafter+1),1),col=2,lty=2,lwd=lwidnum)
lines(axis,100*((1+r.phi.prime)^(1/numyrs)-1)*ones((numperbefore+numperafter+1),1),col=4,lwd=lwidnum)
legend("topleft",cex=1,c("Transition","Pre-Shock BGP","Post-Shock BGP"),lty=c(1,2,1),col=c(1,2,4),pch=c(1,-1,-1),bty="n",lwd=lwidnum)



dev.off()

#welfare calculations

#SET UP STORAGE
welfare.length = 600
u.mat=zeros(welfare.length,6)
betas=zeros(welfare.length,1)
u.mat[1:(T+1),1]=graphout.tf$u
u.mat[1:(T+1),2]=graphout.tf$ustar
u.mat[1:(T+1),3]=graphout.fm$u
u.mat[1:(T+1),4]=graphout.fm$ustar

#FIRST, COMPUTE THE WELFARE WITH NO SHOCK IN THE WEST AND THE EAST
Mprimeval = g.phi * A1; Mval = Mprimeval / (1+g.phi);
Rprimeval = (1-phi) * A1; Rval = Rprimeval / (1+g.phi);
Iprimeval = phi * A1; Ival = Iprimeval / (1+g.phi);

xMval = (1-alpha)^(2/alpha) * (1+r.phi)^(-1/alpha) * H
xMstarval = (1-alpha)^(2/alpha) * (1+r.phi)^(-1/alpha) * q.phi^(1/alpha) * Hstar

xRval = (1-alpha)^(1/alpha) * (1+r.phi)^(-1/alpha) * H
xRstarval = (1-alpha)^(1/alpha) * (1+r.phi)^(-1/alpha) * Hstar

xIval = (1-alpha)^(1/alpha) * (1+r.phi)^(-1/alpha) * q.phi^(-1/alpha) * H
xIstarval = (1-alpha)^(1/alpha) * (1+r.phi)^(-1/alpha) * Hstar

Zval = (g.phi^gamma)/(eta*(gamma-1)+1)

Yval = H^alpha
Yval = Yval * ( Mval * xMval^(1-alpha) + Rval * xRval^(1-alpha) + Ival * xIval^(1-alpha)  )

Cval = Yval - Mprimeval * (xMval + xMstarval) - Rprimeval * xRval - Zval

Ystarval = Hstar^alpha
Ystarval = Ystarval *  (Mval * xMstarval^(1-alpha) + Rval * xRstarval^(1-alpha) + Ival * xIstarval^(1-alpha)    )

Cstarval = Ystarval - Rprimeval * xRstarval - Iprimeval * (xIval + xIstarval)
#THEN, DISCOUNT ALL FLOWS

betas[1]=beta
u.mat[1,5]=Cval
u.mat[1,6]=Cstarval
for (t in (2:welfare.length)){
  
  u.mat[t,5:6] = u.mat[t-1,5:6]*(1+g.phi)
}

for (t in (2:welfare.length)){
  betas[t]=beta*betas[t-1]
}

for (t in ((T+2):welfare.length)) {
  
  u.mat[t,1:4]=(1+g.phi.prime)*u.mat[t-1,1:4]
  
}

Wtf = sum(betas*log(u.mat[,1]))
Wstartf = sum(betas*log(u.mat[,2]))
Wfm = sum(betas*log(u.mat[,3]))
Wstarfm = sum(betas*log(u.mat[,4]))
Wns = sum(betas*log(u.mat[,5]))
Wstarns = sum(betas*log(u.mat[,6]))

x = 100*(exp( (1-beta) *(Wtf-Wfm)  )-1)
xstar = 100*(exp( (1-beta) *(Wstartf-Wstarfm)  )-1)

xgains = 100*(exp( (1-beta) *(Wfm-Wns)  )-1)
xstargains=100*(exp( (1-beta) *(Wstarfm-Wstarns)  )-1)

xgainstf = 100*(exp( (1-beta) *(Wtf-Wns)  )-1)
xstargainstf=100*(exp( (1-beta) *(Wstartf-Wstarns)  )-1)

sink(file="Table_3.txt",append=FALSE)
cat(' ','\n')
cat("########### Table 3 Values",'\n')
cat('Fully Mobile, Short-Term Growth, t=1: ',100*((1+graphout.fm$g[2])^(1/numyrs)-1),'\n')
cat('Trapped Factors, Short-Term Growth, t=1: ',100*((1+graphout.tf$g[2])^(1/numyrs)-1),'\n')
cat('Fully Mobile, Northern Welfare Gains, Full Transition: ',xgains,'\n')
cat('Trapped Factors, Northern Welfare Gains, Full Transition: ',xgainstf,'\n')
sink(file=NULL)


#print stuff for robustness spreadsheet
out.data=parameters


out.data=cbind(out.data,out.data[8]/out.data[7])
colnames(out.data)[length(out.data)]="Hstar/H"

out.data=cbind(out.data,100*((1+g.phi)^(1/numyrs)-1))
colnames(out.data)[length(out.data)]="g.phi"

out.data=cbind(out.data,100*((1+g.phi.prime)^(1/numyrs)-1))
colnames(out.data)[length(out.data)]="g.phi.prime"

out.data=cbind(out.data,100*((1+graphout.tf$g[2])^(1/numyrs)-1))
colnames(out.data)[length(out.data)]="g.TF"

out.data=cbind(out.data,100*((1+graphout.fm$g[2])^(1/numyrs)-1))
colnames(out.data)[length(out.data)]="g.FM"

out.data=cbind(out.data,q.phi)
colnames(out.data)[length(out.data)]="q.phi"

out.data=cbind(out.data,q.phi.prime)
colnames(out.data)[length(out.data)]="q.phi.prime"

out.data=cbind(out.data,xgains)
colnames(out.data)[length(out.data)]="North gains trade"

out.data=cbind(out.data,x)
colnames(out.data)[length(out.data)]="North gains TF"

out.data=cbind(out.data,xstargains)
colnames(out.data)[length(out.data)]="South gains trade"

out.data=cbind(out.data,xstar)
colnames(out.data)[length(out.data)]="South gains TF"

out.data=cbind(out.data,100*log(graphout.tf$M2[2]/graphout.tf$M1[2]))
colnames(out.data)[length(out.data)]="Cross-Section Shock - No Shock"

out.data=cbind(out.data,100*log(graphout.tf$M1[2]/graphout.fm$M1[2]))
colnames(out.data)[length(out.data)]="Cross-Section No Shock - FM"

out.data=cbind(out.data,Wtf)
colnames(out.data)[length(out.data)]="Wtf"

out.data=cbind(out.data,Wfm)
colnames(out.data)[length(out.data)]="Wfm"

out.data=cbind(out.data,Wstarfm)
colnames(out.data)[length(out.data)]="Wstarfm"

out.data=cbind(out.data,Wstartf)
colnames(out.data)[length(out.data)]="Wstartf"

out.data=out.data[,2:length(out.data)]

write.csv(file="outdata.csv",out.data)


#####do decompositions of Northern and Southern output growth into constituent pieces

#Northern FM case
Ymin1_FM = fm.allocations$Y[1]
Yaddtrade_FM = (H^alpha)*(fm.allocations$M[1]*fm.allocations$xM1[1]^(1-alpha) + (fm.allocations$R[1]-fm.allocations$I[2]+fm.allocations$I[1])*(fm.allocations$xR1[1]^(1-alpha) ) + fm.allocations$I[2]*(fm.allocations$xI[1]^(1-alpha)))
Yaddtradeandmkups_FM = (H^alpha)*(fm.allocations$M[1]*fm.allocations$xR1[1]^(1-alpha) + (fm.allocations$R[1]-fm.allocations$I[2]+fm.allocations$I[1])*(fm.allocations$xR1[1]^(1-alpha) ) + fm.allocations$I[2]*(fm.allocations$xI[1]^(1-alpha)))
Y_FM = fm.allocations$Y[2]
NORTH_FM_bar = c(Ymin1_FM,Yaddtrade_FM,Yaddtradeandmkups_FM,Y_FM)/Ymin1_FM


#Southern FM case
Ystarmin1_FM = fm.allocations$Ystar[1]
Ystaraddtrade_FM = fm.allocations$Ystar[1]
Ystaraddtradeandmkups_FM = fm.allocations$Ystar[1]+(Hstar^alpha)*fm.allocations$M[1]*(fm.allocations$xRstar[1]^(1-alpha)-fm.allocations$xMstar1[1]^(1-alpha))
Ystar_FM = fm.allocations$Ystar[2]
SOUTH_FM_bar = c(Ystarmin1_FM,Ystaraddtrade_FM,Ystaraddtradeandmkups_FM,Ystar_FM)/Ystarmin1_FM

#Northern TF Case
Ymin1_TF = tf.allocations$Y[1]
Yaddtrade_TF = (H^alpha)*(tf.allocations$M[1]*tf.allocations$xM1[1]^(1-alpha) + (tf.allocations$R[1]-tf.allocations$I[2]+tf.allocations$I[1])*(tf.allocations$xR1[1]^(1-alpha) ) + tf.allocations$I[2]*(tf.allocations$xI[1]^(1-alpha)))
Yaddtradeandmkups_TF = (H^alpha)*(tf.allocations$M[1]*tf.allocations$xR1[1]^(1-alpha) + (tf.allocations$R[1]-tf.allocations$I[2]+tf.allocations$I[1])*(tf.allocations$xR1[1]^(1-alpha) ) + tf.allocations$I[2]*(tf.allocations$xI[1]^(1-alpha)))
Y_TF = tf.allocations$Y[2]
NORTH_TF_bar = c(Ymin1_TF,Yaddtrade_TF,Yaddtradeandmkups_TF,Y_TF)/Ymin1_TF

#Southern TF Case
Ystarmin1_TF = tf.allocations$Ystar[1]
Ystaraddtrade_TF = tf.allocations$Ystar[1]
Ystaraddtradeandmkups_TF = tf.allocations$Ystar[1]+(Hstar^alpha)*tf.allocations$M[1]*(tf.allocations$xRstar[1]^(1-alpha)-tf.allocations$xMstar1[1]^(1-alpha))
Ystar_TF = tf.allocations$Ystar[2]
SOUTH_TF_bar = c(Ystarmin1_TF,Ystaraddtrade_TF,Ystaraddtradeandmkups_TF,Ystar_TF)/Ystarmin1_TF

#Northern SS Case, pre-shock
Ymin1_SS = fm.allocations$Y[1]
Yaddtrade_SS = (H^alpha)*(fm.allocations$M[1]*fm.allocations$xM1[1]^(1-alpha) + (fm.allocations$R[1]-fm.allocations$g[1]*fm.allocations$I[1])*(fm.allocations$xR1[1]^(1-alpha) ) + fm.allocations$I[1]*(1+fm.allocations$g[1])*(fm.allocations$xI[1]^(1-alpha)))
Yaddtradeandmkups_SS = (H^alpha)*(fm.allocations$M[1]*fm.allocations$xR1[1]^(1-alpha) + (fm.allocations$R[1]-fm.allocations$g[1]*fm.allocations$I[1])*(fm.allocations$xR1[1]^(1-alpha) ) + fm.allocations$I[1]*(1+fm.allocations$g[1])*(fm.allocations$xI[1]^(1-alpha)))
Y_SS = (1+fm.allocations$g[1])*fm.allocations$Y[1]
NORTH_SS_bar = c(Ymin1_SS,Yaddtrade_SS,Yaddtradeandmkups_SS,Y_SS)/Ymin1_SS

#Southern SS Case, pre-shock
Ystarmin1_SS = fm.allocations$Ystar[1]
Ystaraddtrade_SS = fm.allocations$Ystar[1]
Ystaraddtradeandmkups_SS = fm.allocations$Ystar[1]+(Hstar^alpha)*fm.allocations$M[1]*(fm.allocations$xRstar[1]^(1-alpha)-fm.allocations$xMstar1[1]^(1-alpha))
Ystar_SS = (1+fm.allocations$g[1])*fm.allocations$Ystar[1]
SOUTH_SS_bar = c(Ystarmin1_SS,Ystaraddtrade_SS,Ystaraddtradeandmkups_SS,Ystar_SS)/Ystarmin1_SS


#Northern SS Case, post-shock
Ymin1_SS_post = (H^alpha)*(fm.allocations$M[8]*fm.allocations$xM1[8]^(1-alpha) + (fm.allocations$R[8])*(fm.allocations$xR1[8]^(1-alpha) ) + fm.allocations$I[8]*(fm.allocations$xI[8]^(1-alpha)))
Yaddtrade_SS_post = (H^alpha)*(fm.allocations$M[8]*fm.allocations$xM1[8]^(1-alpha) + (fm.allocations$R[8]-fm.allocations$g[8]*fm.allocations$I[8])*(fm.allocations$xR1[8]^(1-alpha) ) + (1+fm.allocations$g[8])*fm.allocations$I[8]*(fm.allocations$xI[8]^(1-alpha)))
Yaddtradeandmkups_SS_post = (H^alpha)*(fm.allocations$M[8]*fm.allocations$xR1[8]^(1-alpha) + (fm.allocations$R[8]-fm.allocations$g[8]*fm.allocations$I[8])*(fm.allocations$xR1[8]^(1-alpha) ) + (1+fm.allocations$g[8])*fm.allocations$I[8]*(fm.allocations$xI[8]^(1-alpha)))
Y_SS_post = (1+fm.allocations$g[8])*fm.allocations$Y[8]
NORTH_SS_post_bar = c(Ymin1_SS_post,Yaddtrade_SS_post,Yaddtradeandmkups_SS_post,Y_SS_post)/Ymin1_SS_post

#Southern SS Case, post-shock
Ystarmin1_SS_post = (Hstar^alpha)*(fm.allocations$M[8]*fm.allocations$xMstar1[8]^(1-alpha) + (fm.allocations$R[8])*(fm.allocations$xRstar[8]^(1-alpha) ) + fm.allocations$I[8]*(fm.allocations$xIstar[8]^(1-alpha)))
Ystaraddtrade_SS_post = (Hstar^alpha)*(fm.allocations$M[8]*fm.allocations$xMstar1[8]^(1-alpha) + (fm.allocations$R[8]-fm.allocations$g[8]*fm.allocations$I[8])*(fm.allocations$xRstar[8]^(1-alpha) ) + (1+fm.allocations$g[8])*fm.allocations$I[8]*(fm.allocations$xIstar[8]^(1-alpha)))
Ystaraddtradeandmkups_SS_post = (Hstar^alpha)*(fm.allocations$M[8]*fm.allocations$xRstar[8]^(1-alpha) + (fm.allocations$R[8]-fm.allocations$g[8]*fm.allocations$I[8])*(fm.allocations$xRstar[8]^(1-alpha) ) + (1+fm.allocations$g[8])*fm.allocations$I[8]*(fm.allocations$xIstar[8]^(1-alpha)))
Ystar_SS_post = (1+fm.allocations$g[8])*fm.allocations$Ystar[8]
SOUTH_SS_post_bar = c(Ystarmin1_SS_post,Ystaraddtrade_SS_post,Ystaraddtradeandmkups_SS_post,Ystar_SS_post)/Ystarmin1_SS_post

#prepare for plotting the growth rates contributed by each component
NORTH_DECOMP_bar = cbind(NORTH_SS_bar,NORTH_FM_bar,NORTH_TF_bar,NORTH_SS_post_bar)
NORTH_DECOMP_bar = 100*(NORTH_DECOMP_bar^(1/numyrs)-1)
NORTH_DECOMP_bar[4,]=NORTH_DECOMP_bar[4,]-NORTH_DECOMP_bar[3,]
NORTH_DECOMP_bar[3,]=NORTH_DECOMP_bar[3,]-NORTH_DECOMP_bar[2,]
NORTH_DECOMP_bar[2,]=NORTH_DECOMP_bar[2,]-NORTH_DECOMP_bar[1,]
NORTH_DECOMP_bar = NORTH_DECOMP_bar[c(2,3,4),]

SOUTH_DECOMP_bar = cbind(SOUTH_SS_bar,SOUTH_FM_bar,SOUTH_TF_bar,SOUTH_SS_post_bar)
SOUTH_DECOMP_bar = 100*(SOUTH_DECOMP_bar^(1/numyrs)-1)
SOUTH_DECOMP_bar[4,]=SOUTH_DECOMP_bar[4,]-SOUTH_DECOMP_bar[3,]
SOUTH_DECOMP_bar[3,]=SOUTH_DECOMP_bar[3,]-SOUTH_DECOMP_bar[2,]
SOUTH_DECOMP_bar[2,]=SOUTH_DECOMP_bar[2,]-SOUTH_DECOMP_bar[1,]
SOUTH_DECOMP_bar = SOUTH_DECOMP_bar[c(2,3,4),]

pdf(file="Figure_10.pdf",pointsize=5)
par(mfrow=c(2,1),mai=c(0.5,0.75,0.5,0.25))
par(ps = fsize, cex = 1, cex.main = 1.5,cex.lab=1.25,cex.axis=1.2)
barplot(NORTH_DECOMP_bar,border=TRUE,space = 0.4,names.arg=c("Pre-Shock BGP","Fully Mobile","Trapped Factors","Post-Shock BGP"),
        ylab="Annual %",main="A: Northern Output Growth Decomposition",xlab="",col=c(1,4,2),ylim=c(0,3.5),xpd=FALSE)
text(0.85,2.55,"New M Goods",font=2,cex=1.25,col=2)
arrows(0.65,2.35,0.75,2.05,code=2,lwd=1.5,angle=45,length=0.1,col=2)
text(1.85,2.9,"Cheaper M to R Goods",font=2,cex=1.25,col=4)
arrows(1.75,2.7,2,1.65,code=2,lwd=1.5,angle=45,length=0.1,col=4)
text(3.0,3.3,"Cheaper R to I Goods",font=2,cex=1.25,col=1)
arrows(3.0,3.1,3.6,1.0,code=2,lwd=1.5,angle=45,length=0.1,col=1)
#dev.off()

par(ps = fsize, cex = 1, cex.main = 1.5,cex.lab=1.25,cex.axis=1.2)
barplot(SOUTH_DECOMP_bar,border=TRUE,space = 0.2,names.arg=c("Pre-Shock BGP","Fully Mobile","Trapped Factors","Post-Shock BGP"),
        ylab="Annual %",main="B: Southern Output Growth Decomposition",xlab="",col=c(1,4,2),ylim=c(0,3.5),xpd=FALSE)
dev.off()
